@@ -19,7 +19,9 @@ import aws_cdk.core._jsii
 import aws_cdk.cx_api._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/app-delivery", "1.49.1", __name__[0:-6], "app-delivery@1.49.1.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/app-delivery", "1.51.0", __name__[0:-6], "app-delivery@1.51.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
